@@ -1,10 +1,5 @@
 var NAVTREEINDEX17 =
 {
-"juce__TargetPlatform_8h_source.html":[3,0,0,0,0,3,9,4],
-"juce__TemporaryFile_8cpp_source.html":[3,0,0,0,0,3,1,13],
-"juce__TemporaryFile_8h_source.html":[3,0,0,0,0,3,1,14],
-"juce__TextDiff_8cpp_source.html":[3,0,0,0,0,3,10,22],
-"juce__TextDiff_8h_source.html":[3,0,0,0,0,3,10,23],
 "juce__ThreadLocalValue_8h_source.html":[3,0,0,0,0,3,11,16],
 "juce__ThreadPool_8cpp_source.html":[3,0,0,0,0,3,11,17],
 "juce__ThreadPool_8h_source.html":[3,0,0,0,0,3,11,18],
@@ -249,5 +244,10 @@ var NAVTREEINDEX17 =
 "structjuce_1_1MPESynthesiserBase.html#aa2b073a25af1218f40cc6f722f100676":[2,0,0,138,18],
 "structjuce_1_1MPESynthesiserBase.html#aa433dfa54bda9c8878bc4b194c108b32":[2,0,0,138,20],
 "structjuce_1_1MPESynthesiserBase.html#aad02cd6fcecee7541c376667286919d7":[2,0,0,138,17],
-"structjuce_1_1MPESynthesiserBase.html#ac1cbff8d031374541deaf1058392197e":[2,0,0,138,3]
+"structjuce_1_1MPESynthesiserBase.html#ac1cbff8d031374541deaf1058392197e":[2,0,0,138,3],
+"structjuce_1_1MPESynthesiserBase.html#ac43f7a6087ee7b92798d3d4a3ba21241":[2,0,0,138,12],
+"structjuce_1_1MPESynthesiserBase.html#ac83a703ed74d37fa716ffab61c169be1":[2,0,0,138,5],
+"structjuce_1_1MPESynthesiserBase.html#aeace267111a1f5dbe0fdf2a1db79f511":[2,0,0,138,9],
+"structjuce_1_1MPESynthesiserBase.html#aebfe93ba9f10abf1f2a5e80debb92bd2":[2,0,0,138,15],
+"structjuce_1_1MPESynthesiserBase.html#aedc2caf7b5961098435c661736db9111":[2,0,0,138,11]
 };
