@@ -1,7 +1,5 @@
 var NAVTREEINDEX3 =
 {
-"classjuce_1_1CharPointer__UTF16.html#a6422c90ef9c521a55eba6f303e30e6a6":[2,0,0,49,36],
-"classjuce_1_1CharPointer__UTF16.html#a6ab602475c2534b5bb330532b9b19d7b":[2,0,0,49,9],
 "classjuce_1_1CharPointer__UTF16.html#a7e91be1fb14a44b599b95359cc7432b9":[2,0,0,49,23],
 "classjuce_1_1CharPointer__UTF16.html#a7ef615a22b111598985c9067805e1137":[2,0,0,49,6],
 "classjuce_1_1CharPointer__UTF16.html#a82f84843f6c82e952b805f564c964298":[2,0,0,49,24],
@@ -249,5 +247,7 @@ var NAVTREEINDEX3 =
 "classjuce_1_1Expression_1_1Scope.html#a68679c2d70d7a7e09981a3f9daabedc3":[2,0,0,67,0,2],
 "classjuce_1_1Expression_1_1Scope.html#a70a2a5655f191040ac4cbf9b775831a3":[2,0,0,67,0,1],
 "classjuce_1_1Expression_1_1Scope_1_1Visitor.html":[2,0,0,67,0,0],
-"classjuce_1_1File.html":[2,0,0,68]
+"classjuce_1_1File.html":[2,0,0,68],
+"classjuce_1_1File.html#a01aa22f7ebb9b06840c2118a5e99964a":[2,0,0,68,74],
+"classjuce_1_1File.html#a064b1fc415ab80156be71aa1a9ababf3":[2,0,0,68,45]
 };
