@@ -1,7 +1,5 @@
 var NAVTREEINDEX8 =
 {
-"classjuce_1_1NamedPipe.html#a9af215d2dd492dc72d7027e029bc74b3":[2,0,0,143,5],
-"classjuce_1_1NamedPipe.html#a9dcb83c89f29a449fba129c7ddab90ac":[2,0,0,143,3],
 "classjuce_1_1NamedPipe.html#aa37c72d4cee557d346998e44522a3f64":[2,0,0,143,0],
 "classjuce_1_1NamedPipe.html#aa8e814abd33bff7b34c37efcc3e1cbf8":[2,0,0,143,6],
 "classjuce_1_1NamedPipe.html#ae6a981ddd3e66cdf1cffb5b0bfd2d800":[2,0,0,143,2],
@@ -37,7 +35,7 @@ var NAVTREEINDEX8 =
 "classjuce_1_1NormalisableRange.html#a05fe252e53625e4081c4da0fc3af3a22":[2,0,0,147,13],
 "classjuce_1_1NormalisableRange.html#a2ca9d9441cdfa183699df4008b417794":[2,0,0,147,17],
 "classjuce_1_1NormalisableRange.html#a36b5ead36ab0859c0343201b8670d540":[2,0,0,147,12],
-"classjuce_1_1NormalisableRange.html#a5f3154324e6ff6c10f3f9c9d05a65119":[2,0,0,147,0],
+"classjuce_1_1NormalisableRange.html#a44c871cc18cd43c316dcd2dad01c80a3":[2,0,0,147,0],
 "classjuce_1_1NormalisableRange.html#a69df9264bc5f6d1b04fefee122ef54e0":[2,0,0,147,1],
 "classjuce_1_1NormalisableRange.html#a71c31eed12b23c7cb1628482114044e6":[2,0,0,147,16],
 "classjuce_1_1NormalisableRange.html#a7935f155d62f394bd67182846f3f0dcc":[2,0,0,147,8],
@@ -249,5 +247,7 @@ var NAVTREEINDEX8 =
 "classjuce_1_1ReadWriteLock.html#a3b6747d6ffa5bb3028cc8f9dc5c70e5d":[2,0,0,158,3],
 "classjuce_1_1ReadWriteLock.html#a78257fb6bbea37b1cf1fbc393174f84a":[2,0,0,158,1],
 "classjuce_1_1ReadWriteLock.html#a7a072cbd5263e969fb80e70139e433e1":[2,0,0,158,4],
-"classjuce_1_1ReadWriteLock.html#a94a8651c1ce41049d9eed7eb67e07217":[2,0,0,158,2]
+"classjuce_1_1ReadWriteLock.html#a94a8651c1ce41049d9eed7eb67e07217":[2,0,0,158,2],
+"classjuce_1_1ReadWriteLock.html#a9668721cf0be4b64da52f71ecba9820d":[2,0,0,158,5],
+"classjuce_1_1ReadWriteLock.html#ae6e522f1242ba8442292840c316cff0f":[2,0,0,158,7]
 };
