@@ -8,7 +8,7 @@ var indexSectionsWithContent =
   5: "acemnoprstv",
   6: "acfjkmopstw",
   7: "abcdfghijklmoprstuw",
-  8: "t"
+  8: "alot"
 };
 
 var indexSectionNames =
